Getting Started
===============


Installation
------------

Using conda
~~~~~~~~~~~

You can install evaldet with conda from the conda-forge channel

.. note::
    Conda package will be available soon. For now, use pip installation

Using pip
~~~~~~~~~

You can also install the package with pip

.. code-block:: console

    pip install evaldet

